@@ -1,7 +1,10 @@
 module Settings.Flavours.Development (developmentFlavour) where
 
+import qualified Data.Set as Set
+
 import Expression
 import Flavour
+import Oracles.Flag
 import Packages
 import {-# SOURCE #-} Settings.Default
 
@@ -10,15 +13,15 @@ developmentFlavour :: Stage -> Flavour
 developmentFlavour ghcStage = defaultFlavour
     { name = "devel" ++ stageString ghcStage
     , args = defaultBuilderArgs <> developmentArgs ghcStage <> defaultPackageArgs
-    , libraryWays = pure [vanilla]
-    , rtsWays = pure [vanilla, debug, threaded, threadedDebug]
+    , libraryWays = pure $ Set.fromList [vanilla]
+    , rtsWays = Set.fromList <$> mconcat [pure [vanilla, debug], targetSupportsThreadedRts ? pure [threaded, threadedDebug]]
     , dynamicGhcPrograms = return False
-    , ghcDebugAssertions = True }
+    , ghcDebugAssertions = (== ghcStage) }
     where
       stageString Stage2 = "2"
       stageString Stage1 = "1"
       stageString Stage3 = "3"
-      stageString s = error ("developmentFlavour not support for " ++ show s)
+      stageString s = error ("developmentFlavour not supported for " ++ show s)
 
 developmentArgs :: Stage -> Args
 developmentArgs ghcStage = do
@@ -28,7 +31,7 @@ developmentArgs ghcStage = do
                                  -- Disable optimization when building Cabal;
                                  -- this saves many minutes of build time.
                                  package cabal ? pure ["-O0"]]
-        , hsLibrary  = notStage0 ? arg "-dcore-lint"
+        , hsLibrary  = notStage0 ? arg "-dlint"
         , hsCompiler = mconcat [stage0 ? arg "-O2",
                                  stage == predStage ghcStage ? pure ["-O0"]]
         , hsGhc      = stage == predStage ghcStage ? pure ["-O0"] }
